@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.javadoc;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.plugins.javadoc;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.plugins.javadoc;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.javadoc;
 
 import org.apache.maven.model.Dependency;
 
@@ -25,8 +24,6 @@ import org.apache.maven.model.Dependency;
  * Provides syntactic sugar for using the standard {@code Dependency}
  * model as a parameter to {@link AbstractJavadocMojo}'s {@code additionalDependencies}.
  */
-public class AdditionalDependency
-    extends Dependency
-{
+public class AdditionalDependency extends Dependency {
     // no op
 }
