@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.javadoc;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,11 @@ package org.apache.maven.plugins.javadoc;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.javadoc;
+
+import java.util.Collections;
+import java.util.LinkedList;
+import java.util.List;
 
 import org.apache.maven.artifact.DependencyResolutionRequiredException;
 import org.apache.maven.plugin.MojoExecutionException;
@@ -28,52 +31,41 @@ import org.apache.maven.plugins.annotations.Mojo;
 import org.apache.maven.plugins.annotations.ResolutionScope;
 import org.apache.maven.project.MavenProject;
 
-import java.util.Collections;
-import java.util.LinkedList;
-import java.util.List;
-
 /**
  * Fix Javadoc documentation and tags for the <code>Test Java code</code> for the project.
- * See <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#wheretags">Where Tags Can
- * Be Used</a>.
  *
+ * @see <a href=https://docs.oracle.com/en/java/javase/17/docs/specs/javadoc/doc-comment-spec.html#where-tags-can-be-used>Where Tags Can Be Used</a>
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
  * @since 2.6
  */
-@Mojo( name = "test-fix", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true )
-@Execute( phase = LifecyclePhase.TEST_COMPILE )
-public class TestFixJavadocMojo
-    extends AbstractFixJavadocMojo
-{
+@Mojo(name = "test-fix", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true)
+@Execute(phase = LifecyclePhase.TEST_COMPILE)
+public class TestFixJavadocMojo extends AbstractFixJavadocMojo {
     /** {@inheritDoc} */
     @Override
-    protected List<String> getProjectSourceRoots( MavenProject p )
-    {
-        return ( p.getTestCompileSourceRoots() == null ? Collections.<String>emptyList()
-                        : new LinkedList<>( p.getTestCompileSourceRoots() ) );
+    protected List<String> getProjectSourceRoots(MavenProject p) {
+        return (p.getTestCompileSourceRoots() == null
+                ? Collections.<String>emptyList()
+                : new LinkedList<>(p.getTestCompileSourceRoots()));
     }
 
     /** {@inheritDoc} */
     @Override
-    protected List<String> getCompileClasspathElements( MavenProject p )
-        throws DependencyResolutionRequiredException
-    {
-        return ( p.getTestClasspathElements() == null ? Collections.<String>emptyList()
-                        : new LinkedList<>( p.getTestClasspathElements() ) );
+    protected List<String> getCompileClasspathElements(MavenProject p) throws DependencyResolutionRequiredException {
+        return (p.getTestClasspathElements() == null
+                ? Collections.<String>emptyList()
+                : new LinkedList<>(p.getTestClasspathElements()));
     }
 
     /** {@inheritDoc} */
     @Override
-    protected String getArtifactType( MavenProject p )
-    {
+    protected String getArtifactType(MavenProject p) {
         return "test-jar";
     }
 
     /** {@inheritDoc} */
     @Override
-    public void execute()
-        throws MojoExecutionException, MojoFailureException
-    {
+    public void execute() throws MojoExecutionException, MojoFailureException {
         // clirr doesn't analyze test code, so ignore it
         ignoreClirr = true;
 
