@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.javadoc;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.plugins.javadoc;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,12 +16,7 @@ package org.apache.maven.plugins.javadoc;
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import java.io.IOException;
-import java.net.InetAddress;
-import java.nio.charset.StandardCharsets;
-import java.util.Base64;
-import java.util.Map;
+package org.apache.maven.plugins.javadoc;
 
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequest;
@@ -31,6 +24,12 @@ import javax.servlet.ServletResponse;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import java.io.IOException;
+import java.net.InetAddress;
+import java.nio.charset.StandardCharsets;
+import java.util.Base64;
+import java.util.Map;
+
 import org.eclipse.jetty.proxy.AsyncProxyServlet;
 import org.eclipse.jetty.proxy.ConnectHandler;
 import org.eclipse.jetty.server.Server;
@@ -44,8 +43,7 @@ import org.eclipse.jetty.servlet.ServletHolder;
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
  * @since 2.6
  */
-class ProxyServer
-{
+class ProxyServer {
     private Server proxyServer;
 
     private ServerConnector serverConnector;
@@ -53,9 +51,8 @@ class ProxyServer
     /**
      * @param proxyServlet the wanted auth proxy servlet
      */
-    public ProxyServer( AuthAsyncProxyServlet proxyServlet )
-    {
-        this( null, 0, proxyServlet );
+    public ProxyServer(AuthAsyncProxyServlet proxyServlet) {
+        this(null, 0, proxyServlet);
     }
 
     /**
@@ -63,16 +60,15 @@ class ProxyServer
      * @param port the server port
      * @param proxyServlet the wanted auth proxy servlet
      */
-    public ProxyServer( String hostName, int port, AuthAsyncProxyServlet proxyServlet )
-    {
-        proxyServer = new Server( );
+    public ProxyServer(String hostName, int port, AuthAsyncProxyServlet proxyServlet) {
+        proxyServer = new Server();
 
-        serverConnector = new ServerConnector( proxyServer );
-        serverConnector.setHost( InetAddress.getLoopbackAddress().getHostName() );
-        serverConnector.setReuseAddress( true );
-        serverConnector.setPort( 0 );
+        serverConnector = new ServerConnector(proxyServer);
+        serverConnector.setHost(InetAddress.getLoopbackAddress().getHostName());
+        serverConnector.setReuseAddress(true);
+        serverConnector.setPort(0);
 
-        proxyServer.addConnector( serverConnector );
+        proxyServer.addConnector(serverConnector);
 
         // Setup proxy handler to handle CONNECT methods
         ConnectHandler proxy = new ConnectHandler();
@@ -82,33 +78,29 @@ class ProxyServer
         ServletContextHandler context = new ServletContextHandler(proxy, "/", true, false);
         ServletHolder appServletHolder = new ServletHolder(proxyServlet);
         context.addServlet(appServletHolder, "/*");
-
     }
 
     /**
      * @return the host name
      */
-    public String getHostName()
-    {
-        return serverConnector.getHost() == null ? InetAddress.getLoopbackAddress().getHostName() : serverConnector.getHost();
+    public String getHostName() {
+        return serverConnector.getHost() == null
+                ? InetAddress.getLoopbackAddress().getHostName()
+                : serverConnector.getHost();
     }
 
     /**
      * @return the host port
      */
-    public int getPort()
-    {
+    public int getPort() {
         return serverConnector.getLocalPort();
     }
 
     /**
      * @throws Exception if any
      */
-    public void start()
-        throws Exception
-    {
-        if ( proxyServer != null )
-        {
+    public void start() throws Exception {
+        if (proxyServer != null) {
             proxyServer.start();
         }
     }
@@ -116,23 +108,17 @@ class ProxyServer
     /**
      * @throws Exception if any
      */
-    public void stop()
-        throws Exception
-    {
-        if ( proxyServer != null )
-        {
+    public void stop() throws Exception {
+        if (proxyServer != null) {
             proxyServer.stop();
         }
         proxyServer = null;
     }
 
-
     /**
      * A proxy servlet with authentication support.
      */
-    static class AuthAsyncProxyServlet
-        extends AsyncProxyServlet
-    {
+    static class AuthAsyncProxyServlet extends AsyncProxyServlet {
         private Map<String, String> authentications;
 
         private long sleepTime = 0;
@@ -140,8 +126,7 @@ class ProxyServer
         /**
          * Constructor for non authentication servlet.
          */
-        public AuthAsyncProxyServlet()
-        {
+        public AuthAsyncProxyServlet() {
             super();
         }
 
@@ -150,8 +135,7 @@ class ProxyServer
          *
          * @param authentications a map of user/password
          */
-        public AuthAsyncProxyServlet( Map<String, String> authentications )
-        {
+        public AuthAsyncProxyServlet(Map<String, String> authentications) {
             this();
 
             this.authentications = authentications;
@@ -163,8 +147,7 @@ class ProxyServer
          * @param authentications a map of user/password
          * @param sleepTime a positive time to sleep the service thread (for timeout)
          */
-        public AuthAsyncProxyServlet( Map<String, String> authentications, long sleepTime )
-        {
+        public AuthAsyncProxyServlet(Map<String, String> authentications, long sleepTime) {
             this();
             this.authentications = authentications;
             this.sleepTime = sleepTime;
@@ -172,57 +155,46 @@ class ProxyServer
 
         /** {@inheritDoc} */
         @Override
-        public void service( ServletRequest req, ServletResponse res )
-            throws ServletException, IOException
-        {
+        public void service(ServletRequest req, ServletResponse res) throws ServletException, IOException {
             final HttpServletRequest request = (HttpServletRequest) req;
             final HttpServletResponse response = (HttpServletResponse) res;
 
-            if ( this.authentications != null && !this.authentications.isEmpty() )
-            {
-                String proxyAuthorization = request.getHeader( "Proxy-Authorization" );
-                if ( proxyAuthorization != null && proxyAuthorization.startsWith( "Basic " ) )
-                {
+            if (this.authentications != null && !this.authentications.isEmpty()) {
+                String proxyAuthorization = request.getHeader("Proxy-Authorization");
+                if (proxyAuthorization != null && proxyAuthorization.startsWith("Basic ")) {
                     String proxyAuth = proxyAuthorization.substring("Basic ".length());
                     String authorization = new String(Base64.getDecoder().decode(proxyAuth), StandardCharsets.UTF_8);
 
-
-                    String[] authTokens = authorization.split( ":" );
+                    String[] authTokens = authorization.split(":");
                     String user = authTokens[0];
                     String password = authTokens[1];
 
-                    if ( this.authentications.get( user ) == null )
-                    {
-                        throw new IllegalArgumentException( user + " not found in the map!" );
+                    if (this.authentications.get(user) == null) {
+                        throw new IllegalArgumentException(user + " not found in the map!");
                     }
 
-                    if ( sleepTime > 0 )
-                    {
-                        try
-                        {
-                            Thread.sleep( sleepTime );
-                        }
-                        catch ( InterruptedException e )
-                        {
+                    if (sleepTime > 0) {
+                        try {
+                            Thread.sleep(sleepTime);
+                        } catch (InterruptedException e) {
                             // nop
                         }
                     }
                     String authPass = this.authentications.get(user);
-                    if ( password.equals( authPass ) )
-                    {
+                    if (password.equals(authPass)) {
                         // could throw exceptions...
-                        super.service( req, res );
+                        super.service(req, res);
                         return;
                     }
                 }
 
                 // Proxy-Authenticate Basic realm="CCProxy Authorization"
-                response.addHeader( "Proxy-Authenticate", "Basic realm=\"Jetty Proxy Authorization\"" );
-                response.setStatus( HttpServletResponse.SC_PROXY_AUTHENTICATION_REQUIRED );
+                response.addHeader("Proxy-Authenticate", "Basic realm=\"Jetty Proxy Authorization\"");
+                response.setStatus(HttpServletResponse.SC_PROXY_AUTHENTICATION_REQUIRED);
                 return;
             }
 
-            super.service( req, res );
+            super.service(req, res);
         }
     }
-}
\ No newline at end of file
+}
