@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.javadoc.stubs;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.plugins.javadoc.stubs;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.plugins.javadoc.stubs;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.javadoc.stubs;
 
 import java.io.File;
 import java.util.ArrayList;
@@ -31,43 +30,38 @@ import org.apache.maven.project.MavenProject;
 /**
  * @author <a href="mailto:oching@apache.org">Maria Odea Ching</a>
  */
-public class AggregateProject1TestMavenProjectStub
-    extends MavenProjectStub
-{
-    public AggregateProject1TestMavenProjectStub()
-    {
-        setGroupId( "org.apache.maven.plugins.maven-javadoc-plugin.unit" );
-        setArtifactId( "aggregate-test-project1" );
-        setVersion( "1.0-SNAPSHOT" );
-        setPackaging( "jar" );
-        setExecutionRoot( true );
+public class AggregateProject1TestMavenProjectStub extends MavenProjectStub {
+    public AggregateProject1TestMavenProjectStub() {
+        setGroupId("org.apache.maven.plugins.maven-javadoc-plugin.unit");
+        setArtifactId("aggregate-test-project1");
+        setVersion("1.0-SNAPSHOT");
+        setPackaging("jar");
+        setExecutionRoot(true);
 
-        Artifact artifact = new JavadocPluginArtifactStub( getGroupId(), getArtifactId(), getVersion(), getPackaging() );
-        artifact.setArtifactHandler( new DefaultArtifactHandlerStub() );
-        setArtifact( artifact );
+        Artifact artifact = new JavadocPluginArtifactStub(getGroupId(), getArtifactId(), getVersion(), getPackaging());
+        artifact.setArtifactHandler(new DefaultArtifactHandlerStub());
+        setArtifact(artifact);
 
         Build build = new Build();
-        build.setFinalName( "aggregate-test-project1" );
-        build.setDirectory( super.getBasedir() + "/target/test/unit/aggregate-test/target" );
-        setBuild( build );
+        build.setFinalName("aggregate-test-project1");
+        build.setDirectory(super.getBasedir() + "/target/test/unit/aggregate-test/target");
+        setBuild(build);
 
         String basedir = getBasedir().getAbsolutePath();
         List<String> compileSourceRoots = new ArrayList<>();
-        compileSourceRoots.add( basedir );
-        setCompileSourceRoots( compileSourceRoots );
+        compileSourceRoots.add(basedir);
+        setCompileSourceRoots(compileSourceRoots);
     }
 
     /** {@inheritDoc} */
     @Override
-    public File getBasedir()
-    {
-        return new File( super.getBasedir() + "/src/test/resources/unit/aggregate-test/project1" );
+    public File getBasedir() {
+        return new File(super.getBasedir() + "/src/test/resources/unit/aggregate-test/project1");
     }
 
     /** {@inheritDoc} */
     @Override
-    public MavenProject getExecutionProject()
-    {
+    public MavenProject getExecutionProject() {
         return this;
     }
 }
